.. _utilipy-xfm:

***********************************
Data Transformation (`utilipy.xfm`)
***********************************

.. currentmodule:: utilipy.data_utils.xfm



Reference/API
=============

.. automodapi:: utilipy.data_utils.xfm
